from argparse import ArgumentParser
import subprocess
import sys

from yaml import safe_load

__metaclass__ = type


def parse_args(argv=None):
    parser = ArgumentParser()
    parser.add_argument('config', help='Config file to use.')
    parser.add_argument('host', help='Machine to run the command on.')
    return parser.parse_args(argv)


class Runner:

    def __init__(self, host):
        self.host = host


class SSHRunner(Runner):
    """Class to run commands via SSH."""

    def run(self, args, out_file):
        subprocess.check_call(['ssh', self.host] + args, stdout=out_file)


def workspace_run(argv=None, runner_factory=SSHRunner):
    args = parse_args(argv)
    with open(args.config) as config_file:
        config = safe_load(config_file)
        runner = runner_factory(args.host)
        runner.run(config['command'], sys.stdout)
